@@ -467,7 +467,7 @@ procman_save_config (ProcData *data)
 		return;
 		
 	procman_save_tree_state (data->client, data->tree, "/apps/procman/proctree");
-	procman_save_tree_state (data->client, data->disk_list, "/apps/procman/disktree");
+	procman_save_tree_state (data->client, data->disk_list, "/apps/procman/disktreenew");
 		
 	gdk_window_get_size (app->window, &width, &height);
 	data->config.width = width;
@@ -507,7 +507,8 @@ main (int argc, char *argv[])
 
 	procman = gnome_program_init ("gnome-system-monitor", VERSION, 
 				      LIBGNOMEUI_MODULE, argc, argv, 
-			    	      GNOME_PARAM_POPT_TABLE, options, NULL);
+			    	      GNOME_PARAM_POPT_TABLE, options, 
+				      GNOME_PARAM_APP_DATADIR,DATADIR, NULL);
 	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/procman.png");
 		    
 	gconf_init (argc, argv, NULL);
